==> estateplat-common-1.2.4-20200710.061408-388-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslShxx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/7/3
 * @description 审核信息
 */
@Table( name ="YCSL_SHXX" )
public class YcslShxx implements Serializable {

    /**
     * 主键
     */
    @Column(name = "SHXXID" )
    @Id
    private String shxxid;

    /**
     * 项目id
     */
    @Column(name = "PROID" )
    private String proid;

    /**
     * 顺序号
     */
    @Column(name = "XH" )
    private Integer xh;

    /**
     * 节点名称
     */
    @Column(name = "JDMC" )
    private String jdmc;

    /**
     * 审核人ID
     */
    @Column(name = "SHRID" )
    private String shrid;

    /**
     * 审核意见
     */
    @Column(name = "SHYJ" )
    private String shyj;

    /**
     * 审核时间
     */
    @Column(name = "SHSJ" )
    private String shsj;

    public String getShxxid() {
        return shxxid;
    }

    public void setShxxid(String shxxid) {
        this.shxxid = shxxid;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getShrid() {
        return shrid;
    }

    public void setShrid(String shrid) {
        this.shrid = shrid;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShsj() {
        return shsj;
    }

    public void setShsj(String shsj) {
        this.shsj = shsj;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20220608.092618-1036-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslShxx.java <==
package cn.gtmap.estateplat.model.acceptance;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/7/3
 * @description 审核信息
 */
@Table(name = "YCSL_SHXX")
public class YcslShxx implements Serializable {

    /**
     * 主键
     */
    @Column(name = "SHXXID")
    @Id
    private String shxxid;

    /**
     * 项目id
     */
    @Column(name = "PROID")
    private String proid;

    /**
     * 顺序号
     */
    @Column(name = "XH")
    private String xh;

    /**
     * 节点名称
     */
    @Column(name = "JDMC")
    private String jdmc;

    /**
     * 审核人ID
     */
    @Column(name = "SHRID")
    private String shrid;

    /**
     * 审核意见
     */
    @Column(name = "SHYJ")
    private String shyj;

    /**
     * 审核时间
     */
    @Column(name = "SHSJ")
    private String shsj;

    public String getShxxid() {
        return shxxid;
    }

    public void setShxxid(String shxxid) {
        this.shxxid = shxxid;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getShrid() {
        return shrid;
    }

    public void setShrid(String shrid) {
        this.shrid = shrid;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getShsj() {
        return shsj;
    }

    public void setShsj(String shsj) {
        this.shsj = shsj;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
